@@ -285,14 +285,14 @@ TheilSen <- function(mydata, pollutant = "nox", deseason = FALSE,
   if (!"layout" %in% names(extra.args)) {
     extra.args$layout <- NULL
   }
-
+  
   vars <- c("date", pollutant)
-
-
+  
+  
   if (!avg.time %in% c("year", "month", "season")) {
     stop("avg.time can only be 'month', 'season' or 'year'.")
   }
-
+  
   ## find time interval
   # need this because if user has a data capture threshold, need to know
   # original time interval
@@ -300,53 +300,55 @@ TheilSen <- function(mydata, pollutant = "nox", deseason = FALSE,
   # More reliable than trying to work it out after conditioning where there
   # may be too few data for the calculation to be reliable
   interval <- find.time.interval(mydata$date)
-
+  
   ## equivalent number of days, used to refine interval for month/year
   days <- as.numeric(strsplit(interval, split = " ")[[1]][1]) /
     24 / 3600
-
+  
   ## better interval, most common interval in a year
   if (days == 31) interval <- "month"
   if (days %in% c(365, 366)) interval <- "year"
-
+  
   ## data checks
   mydata <- checkPrep(mydata, vars, type, remove.calm = FALSE)
-
+  
   ## date formatting for plot
   date.at <- as_date(dateBreaks(mydata$date, date.breaks)$major)
-
+  
   ## date axis formating
   if (is.null(date.format)) {
     formats <- dateBreaks(mydata$date, date.breaks)$format
   } else {
     formats <- date.format
   }
-
-
+  
+  
   ## cutData depending on type
   mydata <- cutData(mydata, type, ...)
-
+  
   ## for overall data and graph plotting
   start.year <- startYear(mydata$date)
   end.year <- endYear(mydata$date)
   start.month <- startMonth(mydata$date)
   end.month <- endMonth(mydata$date)
-
+  
   mydata <- suppressWarnings(
-    timeAverage(mydata,
-    type = type,
-    avg.time = avg.time,
-    statistic = statistic,
-    percentile = percentile,
-    data.thresh = data.thresh,
-    interval = interval
+    timeAverage(
+      mydata,
+      type = type,
+      avg.time = avg.time,
+      statistic = statistic,
+      percentile = percentile,
+      data.thresh = data.thresh,
+      interval = interval,
+      progress = !silent
+    )
   )
-  )
-
+  
   # timeAverage drops type if default
   if ("default" %in% type) mydata$default <- "default"
-
-
+  
+  
   process.cond <- function(mydata) {
     if (all(is.na(mydata[[pollutant]])))
       return(data.frame(
@@ -355,68 +357,68 @@ TheilSen <- function(mydata, pollutant = "nox", deseason = FALSE,
         lower.b = NA, upper.b = NA,
         p.stars = NA
       ))
-
+    
     ## sometimes data have long trailing NAs, so start and end at
     ## first and last data
     min.idx <- min(which(!is.na(mydata[, pollutant])))
     max.idx <- max(which(!is.na(mydata[, pollutant])))
     mydata <- mydata[min.idx:max.idx, ]
-
+    
     ## these subsets may have different dates to overall
     start.year <- startYear(mydata$date)
     end.year <- endYear(mydata$date)
     start.month <- startMonth(mydata$date)
     end.month <- endMonth(mydata$date)
-
+    
     if (avg.time == "month") {
-
+      
       mydata$date <- as_date(mydata$date)
-
+      
       deseas <- mydata[[pollutant]]
-
+      
       ## can't deseason less than 2 years of data
       if (nrow(mydata) <= 24) deseason <- FALSE
-
+      
       if (deseason) {
-
+        
         myts <- ts(mydata[[pollutant]],
                    start = c(start.year, start.month),
                    end = c(end.year, end.month), frequency = 12
         )
-
+        
         # fill any missing data using a Kalman filter
-
+        
         if (any(is.na(myts))) {
-
+          
           fit <- ts(rowSums(tsSmooth(StructTS(myts))[,-2]))
           id <- which(is.na(myts))
-
+          
           myts[id] <- fit[id]
-
+          
         }
-
+        
         ## key thing is to allow the seanonal cycle to vary, hence
         ## s.window should not be "periodic"; set quite high to avoid
         ## overly fitted seasonal cycle
         ## robustness also makes sense for sometimes noisy data
         ssd <- stl(myts, s.window = 35, robust = TRUE, s.degree = 0)
-
+        
         deseas <- ssd$time.series[, "trend"] + ssd$time.series[, "remainder"]
-
+        
         deseas <- as.vector(deseas)
-
+        
       }
-
+      
       all.results <- data.frame(
         date = mydata$date, conc = deseas,
         stringsAsFactors = FALSE
       )
       results <- na.omit(all.results)
-
-
-
+      
+      
+      
     } else {
-
+      
       ## assume annual
       all.results <- data.frame(
         date = as_date(mydata$date),
@@ -425,42 +427,48 @@ TheilSen <- function(mydata, pollutant = "nox", deseason = FALSE,
       )
       results <- na.omit(all.results)
     }
-
+    
     ## now calculate trend, uncertainties etc ###########################
     if (nrow(results) < 6) { ## need enough data to calculate trend, set missing if not
-
+      
       results <- mutate(results,
                         b = NA, a = NA,
                         lower.a = NA, upper.a = NA,
                         lower.b = NA, upper.b = NA,
                         p.stars = NA
       )
-
+      
       return(results)
-
+      
     }
-
+    
     MKresults <- MKstats(results$date, results$conc, alpha, autocor, silent = silent)
-
+    
     ## make sure missing data are put back in for plotting
     results <- merge(all.results, MKresults, by = "date", all = TRUE)
-
+    
     results
   }
-
+  
   # need to work out how to use dplyr if it does not return a data frame due to too few data
+  if (!silent) {
+    message("Taking bootstrap samples. Please wait.", appendLF = TRUE)
+  }
+  
   split.data <- mydata %>%
     group_by(across(type)) %>%
-    do(process.cond(.))
-
-
+    nest() %>%
+    mutate(data = purrr::map(data, process.cond,
+                             .progress = "Taking Bootstrap Samples")) %>%
+    unnest(cols = c(data))
+  
   if (nrow(split.data) < 2) return()
-
-
+  
+  
   ## special wd layout
   # (type field in results.grid called type not wd)
   if (length(type) == 1 &
-    type[1] == "wd" & is.null(extra.args$layout)) {
+      type[1] == "wd" & is.null(extra.args$layout)) {
     ## re-order to make sensible layout
     ## starting point code as of ManKendall
     wds <- c("NW", "N", "NE", "W", "E", "SW", "S", "SE")
@@ -483,91 +491,91 @@ TheilSen <- function(mydata, pollutant = "nox", deseason = FALSE,
   if (!"skip" %in% names(extra.args)) {
     extra.args$skip <- FALSE
   }
-
+  
   ## proper names of labelling #######################################
   strip.dat <- strip.fun(split.data, type, auto.text)
   strip <- strip.dat[[1]]
   strip.left <- strip.dat[[2]]
   pol.name <- strip.dat[[3]]
-
+  
   #### calculate slopes etc ###########################################
-
+  
   split.data <- transform(split.data,
-    slope = 365 * b, intercept = a,
-    intercept.lower = lower.a, intercept.upper = upper.a,
-    lower = 365 * lower.b, upper = 365 * upper.b
+                          slope = 365 * b, intercept = a,
+                          intercept.lower = lower.a, intercept.upper = upper.a,
+                          lower = 365 * lower.b, upper = 365 * upper.b
   )
-
+  
   ## aggregated results
   vars <- c(type, "p.stars")
-
+  
   res2 <- split.data %>%
     group_by(across(vars)) %>%
     summarise(across(everything(), ~ mean(.x, na.rm = TRUE)))
-
+  
   ## calculate percentage changes in slope and uncertainties need
   ## start and end dates (in days) to work out concentrations at those
   ## points percentage change defind as 100.(C.end/C.start -1) /
   ## duration
-
+  
   start <- split.data %>%
     group_by(across(type)) %>%
-    do(head(., 1))
-
+    dplyr::slice_head(n = 1)
+  
   end <- split.data %>%
     group_by(across(type)) %>%
-    do(tail(., 1))
-
+    dplyr::slice_tail(n = 1)
+  
   percent.change <- merge(start, end, by = type, suffixes = c(".start", ".end"))
-
+  
   percent.change <-
     transform(percent.change,
-      slope.percent = 100 * 365 *
-        ((slope.start * as.numeric(date.end) / 365 + intercept.start) /
-          (slope.start * as.numeric(date.start) / 365 + intercept.start) - 1
-        ) /
-        (as.numeric(date.end) - as.numeric(date.start))
+              slope.percent = 100 * 365 *
+                ((slope.start * as.numeric(date.end) / 365 + intercept.start) /
+                   (slope.start * as.numeric(date.start) / 365 + intercept.start) - 1
+                ) /
+                (as.numeric(date.end) - as.numeric(date.start))
     )
   ## got upper/lower intercepts mixed up To FIX?
   percent.change <-
     transform(percent.change,
-      lower.percent = 100 * 365 *
-        ((lower.start * as.numeric(date.end) / 365 + intercept.lower.start) /
-          (
-            lower.start * as.numeric(date.start) / 365 + intercept.lower.start
-          ) - 1
-        ) /
-        (as.numeric(date.end) - as.numeric(date.start))
+              lower.percent = 100 * 365 *
+                ((lower.start * as.numeric(date.end) / 365 + intercept.lower.start) /
+                   (
+                     lower.start * as.numeric(date.start) / 365 + intercept.lower.start
+                   ) - 1
+                ) /
+                (as.numeric(date.end) - as.numeric(date.start))
     )
-
+  
   percent.change <-
     transform(percent.change,
-      upper.percent = 100 * 365 *
-        ((upper.start * as.numeric(date.end) / 365 + intercept.upper.start) /
-          (
-            upper.start * as.numeric(date.start) / 365 + intercept.upper.start
-          ) - 1
-        ) /
-        (as.numeric(date.end) - as.numeric(date.start))
+              upper.percent = 100 * 365 *
+                ((upper.start * as.numeric(date.end) / 365 + intercept.upper.start) /
+                   (
+                     upper.start * as.numeric(date.start) / 365 + intercept.upper.start
+                   ) - 1
+                ) /
+                (as.numeric(date.end) - as.numeric(date.start))
     )
-
+  
   percent.change <- percent.change[, c(
     type, "slope.percent",
     "lower.percent", "upper.percent"
   )]
-
+  
   split.data <- merge(split.data, percent.change, by = type)
-
+  
   res2 <- merge(res2, percent.change, by = type)
   ## #################################################################
-
-
+  
+  
   temp <- paste(type, collapse = "+")
   myform <- formula(paste("conc ~ date| ", temp, sep = ""))
-
+  
   gap <- (max(split.data$date) - min(split.data$date)) / 80
   if (is.null(xlim)) xlim <- range(split.data$date) + c(-1 * gap, gap)
-
+  
   xyplot.args <- list(
     x = myform, data = split.data,
     xlab = quickText(xlab, auto.text),
@@ -583,19 +591,19 @@ TheilSen <- function(mydata, pollutant = "nox", deseason = FALSE,
       ),
       y = list(relation = y.relation, rot = 0)
     ),
-
+    
     panel = function(x, y, subscripts, ...) {
       ## year shading
       panel.shade(split.data, start.year, end.year,
-        ylim = current.panel.limits()$ylim, shade
+                  ylim = current.panel.limits()$ylim, shade
       )
       panel.grid(-1, 0)
-
+      
       panel.xyplot(x, y, type = "b", col = data.col, ...)
-
+      
       # sub.dat <- na.omit(split.data[subscripts, ])
       sub.dat <- split.data[subscripts, ]
-
+      
       # need some data to plot, check if enough information to show trend
       if (nrow(sub.dat) > 0 && !all(is.na(sub.dat$slope))) {
         panel.abline(
@@ -616,27 +624,27 @@ TheilSen <- function(mydata, pollutant = "nox", deseason = FALSE,
           col = trend$col[2], lwd = trend$lwd[2],
           lty = trend$lty[2]
         )
-
+        
         ## for text on plot - % trend or not?
         slope <- "slope"
         lower <- "lower"
         upper <- "upper"
         units <- "units"
-
+        
         if (slope.percent) {
           slope <- "slope.percent"
           lower <- "lower.percent"
           upper <- "upper.percent"
           units <- "%"
         }
-
+        
         ## allow user defined slope text
         if (!is.null(slope.text)) {
           slope.text <- slope.text
         } else {
           slope.text <- paste0(units, "/year")
         }
-
+        
         ## plot top, middle
         panel.text(mean(c(
           current.panel.limits()$xlim[2],
@@ -644,45 +652,48 @@ TheilSen <- function(mydata, pollutant = "nox", deseason = FALSE,
         )),
         current.panel.limits()$ylim[1] + lab.frac *
           (current.panel.limits()$ylim[2] -
-            current.panel.limits()$ylim[1]),
+             current.panel.limits()$ylim[1]),
         paste(round(sub.dat[1, slope], dec.place), " ", "[",
-          round(sub.dat[1, lower], dec.place), ", ",
-          round(sub.dat[1, upper], dec.place), "] ",
-          slope.text, " ", sub.dat[1, "p.stars"],
-          sep = ""
+              round(sub.dat[1, lower], dec.place), ", ",
+              round(sub.dat[1, upper], dec.place), "] ",
+              slope.text, " ", sub.dat[1, "p.stars"],
+              sep = ""
         ),
         cex = lab.cex, adj = c(0.5, 1), col = text.col, font = 2
         )
       }
     }
   )
-
+  
   # reset for extra.args
   xyplot.args <- listUpdate(xyplot.args, extra.args)
-
+  
   # plot
   plt <- do.call(xyplot, xyplot.args)
-
-
+  
+  
   ## output ##########################################################
-
+  
   if (plot) {
-
+    
     if (length(type) == 1) {
       plot(plt)
     } else {
       plot(useOuterStrips(plt, strip = strip, strip.left = strip.left))
     }
-
+    
   }
-
+  
   newdata <- list(
-    main.data = split.data, res2 = res2,
+    main.data = dplyr::tibble(split.data), 
+    res2 = dplyr::tibble(res2),
     subsets = c("main.data", "res2")
   )
-  output <- list(plot = plt, data = newdata, call = match.call())
+  output <- list(plot = plt,
+                 data = newdata,
+                 call = match.call())
   class(output) <- "openair"
-
+  
   invisible(output)
 }
 
@@ -691,48 +702,48 @@ TheilSen <- function(mydata, pollutant = "nox", deseason = FALSE,
 panel.shade <- function(split.data, start.year, end.year, ylim,
                         shade = "grey95") {
   x1 <- as.POSIXct(seq(ISOdate(start.year - 6, 1, 1),
-    ISOdate(end.year + 5, 1, 1),
-    by = "2 years"
+                       ISOdate(end.year + 5, 1, 1),
+                       by = "2 years"
   ), "GMT")
   x2 <- as.POSIXct(seq(ISOdate(start.year + 1 - 6, 1, 1),
-    ISOdate(end.year + 5, 1, 1),
-    by = "2 years"
+                       ISOdate(end.year + 5, 1, 1),
+                       by = "2 years"
   ), "GMT")
-
-
+  
+  
   if (class(split.data$date)[1] == "Date") {
     x1 <- as_date(x1)
     x2 <- as_date(x2)
   }
-
+  
   rng <- range(split.data$conc, na.rm = TRUE) ## range of data
   y1 <- min(split.data$conc, na.rm = TRUE) - 0.1 * abs(rng[2] - rng[1])
   y2 <- max(split.data$conc, na.rm = TRUE) + 0.1 * abs(rng[2] - rng[1])
-
+  
   ## if user selects specific limits
-
+  
   if (!missing(ylim)) {
     y1 <- ylim[1] - 0.1 * abs(ylim[2] - ylim[1])
     y2 <- ylim[2] + 0.1 * abs(ylim[2] - ylim[1])
   }
-
+  
   sapply(seq_along(x1), function(x) lpolygon(c(x1[x], x1[x], x2[x], x2[x]),
-      c(y1, y2, y2, y1),
-      col = shade, border = "grey95"
-    ))
+                                             c(y1, y2, y2, y1),
+                                             col = shade, border = "grey95"
+  ))
 }
 
 MKstats <- function(x, y, alpha, autocor, silent) {
   estimates <- regci(as.numeric(x), y, alpha = alpha, autocor = autocor, pr = silent)$regci
-
+  
   p <- estimates[2, 5]
-
+  
   if (p >= 0.1) stars <- ""
   if (p < 0.1 & p >= 0.05) stars <- "+"
   if (p < 0.05 & p >= 0.01) stars <- "*"
   if (p < 0.01 & p >= 0.001) stars <- "**"
   if (p < 0.001) stars <- "***"
-
+  
   results <-
     data.frame(
       date = x,
@@ -746,6 +757,6 @@ MKstats <- function(x, y, alpha, autocor, silent) {
       p.stars = stars,
       stringsAsFactors = FALSE
     )
-
+  
   results
 }
