@@ -167,7 +167,7 @@ polarAnnulus <-
            alpha = 1,
            plot = TRUE,
            ...) {
-    
+
   ## get rid of R check annoyances
   wd <- u <- v <- z <- all.dates <- NULL
 
@@ -390,123 +390,123 @@ polarAnnulus <-
       percentile = tapply(mydata[, pollutant], list(time.cut, wd.cut), function(x)
         quantile(x, probs = percentile / 100, na.rm = TRUE))
     )
-    
+
     binned <- as.vector(binned)
-    
+
     ## frequency - remove points with freq < min.bin
     bin.len <- tapply(mydata[, pollutant], list(time.cut, wd.cut), length)
     binned.len <- as.vector(bin.len)
-    
+
     ids <- which(binned.len < min.bin)
     binned[ids] <- NA
-    
+
     ## data to predict over
     time.seq <- ws.wd$time.seq
     wd <- ws.wd$wd
-    
+
     input.data <- expand.grid(
       time.seq = seq(0, 10, length = len.int),
       wd = seq(0, 360, length = len.int)
     )
     ###################### Smoothing#################################################
-    
+
     ## run GAM to make a smooth surface
     if (force.positive) n <- 0.5 else n <- 1
-    
+
     input <- data.frame(binned, time.seq, wd)
-    
+
     ## note use of cyclic smooth for the wind direction component
     Mgam <- gam(binned ^ n ~ te(time.seq, wd, k = k, bs = c("tp", "cc")), data = input)
-    
-    
+
+
     pred <- predict.gam(Mgam, input.data)
     pred <- pred ^ (1 / n)
-    
+
     input.data <- cbind(input.data, pred)
-    
+
     if (exclude.missing) {
-      
+
       ## exclude predictions too far from data (from mgcv)
       x <- seq(0, 10, length = len.int)
       y <- seq(0, 360, length = len.int)
       res <- len.int
       wsp <- rep(x, res)
       wdp <- rep(y, rep(res, res))
-      
+
       #  ind <- exclude.too.far(wsp, wdp, mydata$trend, mydata$wd, dist = 0.03)
       ## data with gaps caused by min.bin
       all.data <- na.omit(data.frame(time.seq = ws.wd$time.seq, wd = ws.wd$wd, binned))
       ind <- with(all.data, exclude.too.far(wsp, wdp, time.seq, wd, dist = 0.03))
-      
+
       input.data$pred[ind] <- NA
       pred <- input.data$pred
     }
-    
+
     #############################################################################
     ## transform to new coords - probably more efficient way of doing this
     ## need to transform to/from annulus to a cartesian coords
-    
+
     ## new grid for plotting (the annulus)
     new.data <- expand.grid(
       u = seq(-upper - d, upper + d, by = int),
       v = seq(-upper - d, upper + d, by = int), z = NA, wd = NA,
       time.val = NA
     )
-    
+
     new.data$id <- seq(nrow(new.data))
-    
+
     ## calculate wd and time.val in on annulus in original units (helps with debugging)
     ## essentially start with final grid (annulus) and work backwards to find original data point in
     ## original coordinates
     new.data <- within(new.data, time.val <- (u ^ 2 + v ^ 2) ^ 0.5 - upper)
     new.data <- within(new.data, wd <- 180 * atan2(u, v) / pi)
     new.data <- within(new.data, wd[wd < 0] <- wd[wd < 0] + 360) ## correct negative wds
-    
+
     ## remove ids outside range
     ids <- with(new.data, which((u ^ 2 + v ^ 2) ^ 0.5 > d + upper | (u ^ 2 + v ^ 2) ^ 0.5
                                 < upper))
     new.data$wd[ids] <- NA
     new.data$time.val[ids] <- NA
-    
+
     ## ids where there are data
     ids <- new.data$id[!is.na(new.data$wd)]
-    
+
     ## indexes in original (cartesian) coordinates
     id.time <- round((2 * d / int) * new.data$time.val[ids] / 10) + 1
     id.wd <- round((2 * d / int) * new.data$wd[ids] / 360) + 1
-    
+
     ## predicted values as a matrix
     pred <- matrix(pred, nrow = len.int, ncol = len.int)
-    
+
     ## match the ids with predictions
     new.data$z[ids] <- sapply(seq_along(ids), function(x) pred[id.time[x], id.wd[x]])
-    
+
     new.data
   }
-  
+
   ## more compact way?  Need to test
-  
   results.grid <- mydata %>%
     group_by(across(type)) %>%
-    do(prepare.grid(.))
-  
-  
+    nest() %>%
+    mutate(data = purrr::map(data, prepare.grid)) %>%
+    unnest(cols = c(data))
+
   ## normalise by divining by mean conditioning value if needed
   if (normalise) {
     results.grid <- results.grid %>%
       group_by(across(type)) %>%
       mutate(z = z / mean(z, na.rm = TRUE))
-    
+
     if (missing(key.footer)) key.footer <- "normalised \nlevel"
   }
-  
+
   ## proper names of labelling ###################################################
   strip.dat <- strip.fun(results.grid, type, auto.text)
   strip <- strip.dat[[1]]
   strip.left <- strip.dat[[2]]
   pol.name <- strip.dat[[3]]
-  
-  
+
+
   ## auto-scaling
   nlev <- 200 # preferred number of intervals
   ## handle missing breaks arguments
@@ -519,20 +519,20 @@ polarAnnulus <-
     labs <- labs[labs >= min(breaks) & labs <= max(breaks)]
     at <- labs
   } else {
-    
+
     ## handle user limits and clipping
     breaks <- seq(min(limits), max(limits), length.out = nlev)
     labs <- pretty(breaks, 7)
     labs <- labs[labs >= min(breaks) & labs <= max(breaks)]
     at <- labs
-    
+
     ## case where user max is < data max
     if (max(limits) < max(results.grid[["z"]], na.rm = TRUE)) {
       id <- which(results.grid[["z"]] > max(limits))
       results.grid[["z"]][id] <- max(limits)
       labs[length(labs)] <- paste(">", labs[length(labs)])
     }
-    
+
     ## case where user min is > data min
     if (min(limits) > min(results.grid[["z"]], na.rm = TRUE)) {
       id <- which(results.grid[["z"]] < min(limits))
@@ -540,12 +540,12 @@ polarAnnulus <-
       labs[1] <- paste("<", labs[1])
     }
   }
-  
+
   nlev2 <- length(breaks)
-  
+
   col <- openColours(cols, (nlev2 - 1))
   col.scale <- breaks
-  
+
   #################
   ## scale key setup
   #################
@@ -555,12 +555,12 @@ polarAnnulus <-
     footer = key.footer, header = key.header,
     height = 1, width = 1.5, fit = "all"
   )
-  
+
   legend <- makeOpenKeyLegend(key, legend, "polarAnnulus")
-  
+
   temp <- paste(type, collapse = "+")
   myform <- formula(paste("z ~ u * v | ", temp, sep = ""))
-  
+
   levelplot.args <- list(
     x = myform, results.grid, axes = FALSE,
     as.table = TRUE,
@@ -571,10 +571,10 @@ polarAnnulus <-
     scales = list(draw = FALSE),
     strip = strip,
     sub = sub,
-    
+
     len <- upper + d + 3,
     xlim = c(-len, len), ylim = c(-len, len),
-    
+
     panel = function(x, y, z, subscripts, ...) {
       panel.levelplot(
         x, y, z,
@@ -585,18 +585,18 @@ polarAnnulus <-
         labels = FALSE,
         alpha.regions = alpha
       )
-      
+
       ## add axis line to central polarPlot
       llines(c(upper, upper + d), c(0, 0), col = "grey20")
       llines(c(0, 0), c(-upper, -upper - d), col = "grey20")
-      
+
       ## add axis line to central polarPlot
       llines(c(0, 0), c(upper, upper + d), col = "grey20")
       llines(c(-upper, -upper - d), c(0, 0), col = "grey20")
-      
+
       add.tick <- function(n, start = 0, end = 0) {
         ## start is an offset if time series does not begin in January
-        
+
         ## left
         lsegments(seq(-upper - start, -upper - d + end, length = n),
                   rep(-.5, n),
@@ -626,7 +626,7 @@ polarAnnulus <-
           seq(-upper - start, -upper - d + end, length = n)
         )
       }
-      
+
       label.axis <- function(x, lab1, lab2, ticks) {
         ltext(x, upper, lab1, cex = 0.7, pos = 4)
         ltext(x, upper + d, lab2, cex = 0.7, pos = 4)
@@ -635,7 +635,7 @@ polarAnnulus <-
         ltext(-x, -upper - d, lab2, cex = 0.7, pos = 2)
         add.tick(ticks)
       }
-      
+
       if (period == "trend") {
         if (date.pad) {
           date.start <- min(all.dates$date)
@@ -644,12 +644,12 @@ polarAnnulus <-
           date.start <- min(mydata$date)
           date.end <- max(mydata$date)
         }
-        
+
         label.axis(0, format(date.start, "%d-%b-%Y"), format(date.end, "%d-%b-%Y"), 2)
-        
+
         ## add ticks at 1-Jan each year (could be missing dates)
         days <- seq(as.Date(date.start), as.Date(date.end), by = "day")
-        
+
         if (length(days) > 365) {
           ## find number of Januarys
           num.jans <- which(format(days, "%j") == "001")
@@ -657,7 +657,7 @@ polarAnnulus <-
           start <- 10 * (num.jans[1] - 1) / length(days)
           end <- 10 - 10 * (num.jans[ticks] - 1) / length(days)
           if (length(num.jans) > 0) add.tick(ticks, start, end)
-          
+
           ## mark montly intervals (approx)
         } else {
           ## find number of 01s
@@ -668,23 +668,23 @@ polarAnnulus <-
           if (length(num.jans) > 0) add.tick(ticks, start, end)
         }
       }
-      
+
       if (period == "season") {
         label.axis(
           0, format(ISOdate(2000, 1, 1), "%B"),
           format(ISOdate(2000, 12, 1), "%B"), 13
         )
       }
-      
+
       if (period == "hour") label.axis(0, "0", "23", 7)
-      
+
       if (period == "weekday") {
         local.weekdays <- format(ISOdate(2000, 1, 1:14), "%A")[order(format(ISOdate(2000, 1, 1:14), "%w"))]
         loc.sunday <- local.weekdays[1]
         loc.saturday <- local.weekdays[length(local.weekdays)]
         label.axis(0, loc.sunday, loc.saturday, 8)
       }
-      
+
       ## text for directions
       ltext(-upper - d - 1.5, 0, "W", cex = 0.7)
       ltext(0, -upper - d - 1.5, "S", cex = 0.7)
@@ -692,14 +692,14 @@ polarAnnulus <-
       ltext(upper + d + 1.5, 0, "E", cex = 0.7)
     }
   )
-  
+
   # reset for extra.args
   levelplot.args <- listUpdate(levelplot.args, extra.args)
-  
+
   # plot
   plt <- do.call(levelplot, levelplot.args)
-  
-  
+
+
   #################
   # output
   #################
@@ -713,6 +713,6 @@ polarAnnulus <-
   newdata <- results.grid
   output <- list(plot = plt, data = newdata, call = match.call())
   class(output) <- "openair"
-  
+
   invisible(output)
   }
