@@ -1877,7 +1877,13 @@ addTraj <- function(mydata, subscripts, Args, z, lty, myColors,
 
       pnts <- mydata %>%
         group_by(across(vars)) %>%
-        do(head(., 1))
+        dplyr::slice_head(n = 1)
+
+      if (length(unique(pnts$lon)) == 1 & length(unique(pnts$lat)) == 1) {
+        pnts <- mydata %>%
+          group_by(across(vars)) %>%
+          dplyr::slice_tail(n = 1)
+      }
 
       pnts <- merge(
         pnts, Args$clusters,
